identifier property
It is the items identifier. This is necessary both when creating
the layout and storing it in memory, and this identifier helps
determine the Widget that itemBuilder will return.
Implementation
String identifier;
It is the items identifier. This is necessary both when creating
the layout and storing it in memory, and this identifier helps
determine the Widget that itemBuilder will return.
String identifier;