EditModeBackgroundStyle class
In edit mode, dashboard background are painted with lines and a rect if any items is editing.
The lines show where the slots begin and end, along with the
verticalSpace and the horizontalSpace.
Filling shows the actual location of the editing item. This pan/move also shows where the item will go when released. It is recommended not to use very obscure colors to reflect the sense of editing well.
Constructors
Properties
- dualLineHorizontal → bool
-
If dualLineVertical lines draw exactly slots ends and starts
horizontally.
Else only one line draw center of the verticalSpace.
final
- dualLineVertical → bool
-
If dualLineVertical lines draw exactly slots ends and starts vertically.
Else only one line draw center of the horizontalSpace.
final
- fillColor → Color
-
Editing item background filling color.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lineColor → Color
-
Line color
final
- lineWidth → double
-
Line thickness.
final
- outherRadius → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override